@@ -1,5 +1,5 @@
 /* 
- * Copyright (C) 2006 Piotr Pokora <piotrek.pokora@gmail.com>
+ * Copyright (C) 2006, 2009 Piotr Pokora <piotrek.pokora@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published
@@ -81,7 +81,39 @@ static void __unset_subkey_valuelist (gpointer value)
 	}
 }
 
-/* Creates new Midgard Collector object instance */
+/**
+ * midgard_collector_new:
+ * @mgd: #MidgardConnection instance
+ * @typename: name of given class, which collector is initialized for 
+ * @domain: collection' domain
+ * @value: domain's constraint value
+ * 
+ * @typename should be any #MidgardDBObject derived class name.
+ * @domain is property name which is registered for given class, and should not be 
+ * unique per object or record. In other words, @domain is a common property (and value)
+ * for group of objects expected in collection.
+ * @value must be of domain property type, and is owned by #MidgardCollector instance.
+ * If you need reuse given value, make a copy. 
+ *
+ * Cases to return NULL:
+ *
+ * <itemizedlist>
+ * <listitem><para>
+ * @mgd #MidgardConnection instance is invalid
+ * </para></listitem>
+ * <listitem><para>
+ * @typename is not registered in GType system or it's not #MidgardDBObject derived 
+ * </para></listitem>
+ * <listitem><para>
+ * @domain property is not registered for given @typename class 
+ * </para></listitem>
+ * <listitem><para>
+ * @value is of invalid type
+ * </para></listitem>
+ * </itemizedlist> 
+ * 
+ * Returns: #MidgardCollector instance, or %NULL on failure 
+ */ 
 MidgardCollector *midgard_collector_new(
 		MidgardConnection *mgd, const gchar *typename, 
 		const gchar *domain, GValue *value)
@@ -102,9 +134,13 @@ MidgardCollector *midgard_collector_new(
 	midgard_query_builder_add_constraint(self->priv->builder,
 			domain,
 			"=", value);
+
+	MidgardDBObjectClass *klass = MIDGARD_DBOBJECT_CLASS(self->priv->klass);
 	MidgardQueryConstraint *constraint = midgard_query_constraint_new();
-	if(!midgard_core_qb_parse_property(self->priv->builder,
-				&constraint, domain)) {
+	midgard_query_constraint_set_builder(constraint, self->priv->builder);
+	midgard_query_constraint_set_class(constraint, klass);
+
+	if(!midgard_query_constraint_parse_property(&constraint, klass, domain)) {
 		
 		g_object_unref(constraint);
 		
@@ -138,15 +174,49 @@ MidgardCollector *midgard_collector_new(
 	return self;
 }
 
-/* Sets key property for the given MidgardCollector object. */
+/** 
+ * midgard_collector_set_key_property:
+ * @self: #MidgardCollector instance
+ * @key: property name which must be a key
+ * @value: optional value of key's constraint
+ * 
+ * If @value is explicitly set to NULL , then all key property name's records
+ * are selected from database and set in internal collector's resultset. 
+ * If not, key property name and its value is used as constraint to limit selected
+ * records from database. In latter case add_value_property method should be invoked.
+ * GValue value passed as third argument is owned by Midgard Collector. If value
+ * should be reused, its copy should be passed to constructor.
+ * 
+ * Cases to return FALSE:
+ *
+ * <itemizedlist> 
+ * <listitem><para>
+ * @self #MidgardCollector instance is invalid
+ * </para></listitem>
+ * <listitem><para>
+ * @key property is not registered for the @typename class 
+ * </para></listitem>
+ * <listitem><para>
+ * @value is of invalid type
+ * </para></listitem>
+ * <listitem><para>
+ * @key property is already set for @self #MidgardCollector 
+ * </para></listitem>
+ * </itemizedlist>
+ *
+ * Returns: %TRUE if key has been set, %FALSE otherwise 
+ */
 gboolean midgard_collector_set_key_property(
 		MidgardCollector *self, const gchar *key, GValue *value)
 {
 	g_assert(self != NULL);
 
+	MidgardDBObjectClass *klass = MIDGARD_DBOBJECT_CLASS(g_type_class_peek(self->priv->builder->priv->type));
 	MidgardQueryConstraint *constraint = midgard_query_constraint_new();
-	if(!midgard_core_qb_parse_property(self->priv->builder,
-				&constraint, key)) {
+	midgard_query_constraint_set_builder(constraint, self->priv->builder);
+	midgard_query_constraint_set_class(constraint, klass);
+
+	if(!midgard_query_constraint_parse_property(&constraint, klass, key)) {
 		
 		g_object_unref(constraint);
 		return FALSE;
@@ -174,7 +244,29 @@ gboolean midgard_collector_set_key_property(
 	return TRUE;
 }
 
-/* Adds value property for the given MidgardCollector object.*/
+/**
+ * midgard_collector_add_value_property:
+ * @self: #MidgardCollector instance
+ * @value: property name
+ *
+ * Cases to return FALSE:
+ * <itemizedlist>
+ * <listitem><para>
+ * @self, #MidgardCollector object is invalid
+ * </para></listitem>
+ * <listitem><para>
+ * @value property is not registered for the @class, which has been initialized for given #MidgardCollector
+ * </para></listitem> 
+ * </itemizedlist>
+ * 
+ * Number of value properties added to Midgard Collector is limited by
+ * the number of properties registered for type which has been initialized
+ * for the given #MidgardCollector instance.
+ * 
+ * @See: midgard_query_builder_add_constraint() for available property name pattern
+ *
+ * Returns: %TRUE if named value property has been added, %FALSE otherwise
+ */ 
 gboolean midgard_collector_add_value_property(
 		MidgardCollector *self, const gchar *value)
 {
@@ -185,10 +277,13 @@ gboolean midgard_collector_add_value_property(
 		g_warning("Collector's key is not set. Call set_key_property method");
 		return FALSE;
 	}
-
+	
+	MidgardDBObjectClass *klass = MIDGARD_DBOBJECT_CLASS(g_type_class_peek(self->priv->builder->priv->type));
 	MidgardQueryConstraint *constraint = midgard_query_constraint_new();
-	if(!midgard_core_qb_parse_property(self->priv->builder,
-				&constraint, value)) {
+	midgard_query_constraint_set_builder(constraint, self->priv->builder);
+	midgard_query_constraint_set_class(constraint, klass);
+
+	if(!midgard_query_constraint_parse_property(&constraint, klass, value)) {
 		
 		g_object_unref(constraint);
 		return FALSE;
@@ -205,10 +300,41 @@ gboolean midgard_collector_add_value_property(
 	return TRUE;
 }
 
-/* Sets ( or adds  new key ) and new key's value for the given MidgardCollector. */
-gboolean midgard_collector_set(
-		MidgardCollector *self, 
-		const gchar *key, const gchar *subkey, GValue *value)
+/**
+ * midgard_collector_set:
+ * @self: #MidgardCollector instance
+ * @key: key name for which @subkey&@value pair should be set
+ * @subkey: property name which is a subkey
+ * @value: value for given @subkey
+ *  
+ * Cases to return FALSE:
+ * <itemizedlist>
+ * <listitem><para>
+ * @self, #MidgardCollector instance is invalid
+ * </para></listitem>
+ * <listitem><para>
+ * @subkey property name is not registered for collestor's class
+ * </para></listitem>
+ * <listitem><para>
+ * @value is of invalid type
+ * </para></listitem>
+ * </itemizedlist>
+ * 
+ * If the key is already added to MidgardCollector then its value 
+ * (as subkey&value pair) is destroyed and new one is set. 
+ * In other case new key and its subkey&value pair is added  to collector.
+ * 
+ * Key used in this function is a value returned ( or set ) for collector's key.
+ * Keys are collection of values returned from property fields.  
+ * Subkey is an explicit  property name.
+ *
+ * GValue @value argument is owned by MidgardCollector.
+ * If value should be reused, its copy should be passed as method argument.
+ * 
+ * Returns: %TRUE, if key's value has been set, %FALSE otherwise
+ */
+gboolean 
+midgard_collector_set (MidgardCollector *self, const gchar *key, const gchar *subkey, GValue *value)
 {
 	g_assert(self != NULL);
 	GQuark keyquark = g_quark_from_string(key);
@@ -276,9 +402,19 @@ gboolean midgard_collector_set(
 	return TRUE;
 }
 
-/* Get key's value for the given MidgardCollector object. */
-GData *midgard_collector_get(
-		MidgardCollector *self, const gchar *key)
+/**
+ * midgard_collector_get:
+ * @self: #MidgardCollector instance
+ * @key: name of the key to look for
+ * 
+ * GData keys ( collector's subkeys ) are inserted to GData as
+ * Quarks , so you must call g_quark_to_string if you need to get strings 
+ * ( e.g. implementing hash table for language bindings ).
+ *
+ * Returns: #GData for the given key or %NULL if key is not found in collection
+ */ 
+GData*
+midgard_collector_get (MidgardCollector *self, const gchar *key)
 {
 	g_assert(self);
 
@@ -292,9 +428,16 @@ GData *midgard_collector_get(
 			g_quark_from_string(key));
 }
 
-/* Get subkey's value */
-GValue *midgard_collector_get_subkey(
-		MidgardCollector *self, const gchar *key, const gchar *subkey)
+/**
+ * midgard_collector_get_subkey:
+ * @self: #MidgardCollector instance
+ * @key: name of the key 
+ * @subkey: name of key's subkey to look for
+ * 
+ * Returns: subkey's #GValue value or %NULL if not found
+ */
+GValue*
+midgard_collector_get_subkey (MidgardCollector *self, const gchar *key, const gchar *subkey)
 {
 	g_assert(self);
 
@@ -343,10 +486,32 @@ static void __merge_datalist (	GQuark key_id,
 			_unset_subkey_value);
 }
 
-/* Merges collection's keys and its values. */
-gboolean midgard_collector_merge(
-		MidgardCollector *self, MidgardCollector *mc, 
-		gboolean overwrite)
+/**
+ * midgard_collector_merge:
+ * @self: #MidgardCollector instance
+ * @mc: #MidgardCollector instance 
+ * @overwrite: whether overwrite collector's keys
+ *
+ *
+ * If third overwrite parameter is set as TRUE then all keys which exists 
+ * in @self and @mc collector's instance will be oberwritten in @self colection
+ * instance. If set as FALSE , only those keys will be added, which do not exist
+ * in @self collection and exist in @mc collection.
+ * 
+ * Cases to return FALSE:
+ * <itemizedlist>
+ * <listitem><para>
+ * Second argument is not valid #MidgardCollector 
+ * </para></listitem>
+ * <listitem><para>
+ * @mc, #MidgardCollector has no keys collection
+ * </para></listitem>
+ * </itemizedlist>
+ * 
+ * Returns: %TRUE if collections has been merged, %FALSE otherwise
+ */ 
+gboolean 
+midgard_collector_merge (MidgardCollector *self, MidgardCollector *mc, gboolean overwrite)
 {
 	g_assert(self);
 	g_assert(mc);
@@ -416,9 +581,18 @@ static void __get_collection_keys (	GQuark key_id,
 			(gchar *)g_quark_to_string(key_id));
 }
 
-/* List all keys in collection */
-gchar **midgard_collector_list_keys(
-		MidgardCollector *self)
+/**
+ * midgard_collector_list_key:
+ * @self: #MidgardCollector instance
+ * 
+ * Returned array of string is newly created array with pointers to each string 
+ * in array. It should be freed without any need to free each string.
+ * g_free (instead of g_strfreev) should be used to free returned list.
+ * 
+ * Returns: %NULL terminated array of strings or %NULL
+ */
+gchar**
+midgard_collector_list_keys (MidgardCollector *self)
 {	
 	g_assert(self);
 
@@ -462,7 +636,15 @@ gchar **midgard_collector_list_keys(
 	return NULL;
 }
 
-/* Removes key and associated value for the given MidgardCollector object.*/
+/**
+ * midgard_collector_remove_key:
+ * @self: #MidgardCollector instance
+ * @key: name of the key in collector's collection
+ * 
+ * Removes key and associated value from the given #MidgardCollector instance. 
+ * 
+ * Returns: %TRUE if key (and its value) has been removed from collection, %FALSE otherwise  
+ */
 gboolean midgard_collector_remove_key(
 		MidgardCollector *self, const gchar *key)
 {
@@ -483,15 +665,6 @@ gboolean midgard_collector_remove_key(
 	return TRUE;
 }
 
-/* Destroys given MidgardCollector object. */
-void midgard_collector_destroy(
-		MidgardCollector *self)
-{
-	g_assert(self);
-	g_object_unref(self);
-}
-
-
 /* Parent methods re-implementation */
 
 gboolean midgard_collector_add_constraint(
@@ -565,24 +738,6 @@ void midgard_collector_set_limit(
 				self->priv->builder, limit);
 }
 
-void midgard_collector_set_lang(
-		MidgardCollector *self, gint lang)
-{
-	g_assert(self);
-	MIDGARD_QUERY_BUILDER_GET_CLASS(
-			self->priv->builder)->set_lang(
-				self->priv->builder, lang);
-}
-
-void midgard_collector_unset_languages(
-		MidgardCollector *self)
-{
-	g_assert(self != NULL);
-	MIDGARD_QUERY_BUILDER_GET_CLASS(
-			self->priv->builder)->unset_languages(
-				self->priv->builder);
-}
-
 void midgard_collector_count(
 		MidgardCollector *self)
 {
@@ -590,17 +745,74 @@ void midgard_collector_count(
 	return;
 }
 
-gboolean midgard_collector_include_deleted(
-		MidgardCollector *self)
+gboolean midgard_collector_include_deleted(MidgardCollector *self)
 {
 	g_assert(self != NULL);
 	MIDGARD_QUERY_BUILDER_GET_CLASS(
 			self->priv->builder)->include_deleted(
 				self->priv->builder);
+
+	return TRUE;
 }
 
-gboolean midgard_collector_execute(
-		MidgardCollector *self)
+/*
+static void __set_value(GValue *val, gchar *field_value)
+{
+	switch(G_VALUE_TYPE(val)){
+		
+		case G_TYPE_STRING:
+			g_value_set_string(val, (gchar *)field_value);
+			break;
+		
+		case G_TYPE_UINT:
+			g_value_set_uint(val, atoi(field_value));
+			break;
+		
+		case G_TYPE_INT:
+			g_value_set_int(val, atoi(field_value));
+			break;
+		
+		case G_TYPE_FLOAT:
+			g_value_set_float(val, g_ascii_strtod(field_value, NULL));
+			break;
+		
+		case G_TYPE_BOOLEAN:
+			g_value_set_boolean(val, atoi(field_value));
+			break;
+	}
+}
+*/
+
+/**
+ * midgard_collector_execute;
+ * @self: #MidgardCollector instance
+ * 
+ * Executes SQL query and set internal keys&values collection.
+ *
+ * Overwritten #MidgardQueryBuilder execute method.
+ * Unlike QB's execute method this one returns boolean value.
+ * Resultset is stored inernally by #MidgardCollector instance.
+ *
+ * Cases to return FALSE:
+ * <itemizedlist>
+ * <listitem><para>
+ * No key is associated, midgard_collector_set_key_property()
+ * </para></listitem>
+ * <listitem><para>
+ * No value property is associated, midgard_collector_add_value_property()
+ * </para></listitem>
+ * <listitem><para>
+ * Database provider returned SQL query syntax error
+ * </para></listitem>
+ * <listitem><para>
+ * No record(s) matched  
+ * </para></listitem>
+ * </itemizedlist>
+ * 
+ * Returns: %TRUE in success, %FALSE otherwise
+ */ 
+gboolean 
+midgard_collector_execute (MidgardCollector *self)
 {
 	g_assert(self);
 
@@ -702,10 +914,6 @@ gboolean midgard_collector_execute(
 			
 			if (ret_fields == 1){
 
-				gda_value =
-					midgard_data_model_get_value_at(
-							model, 0, rows);
-
 				midgard_collector_set(self,
 						g_value_dup_string((GValue*)ck_value),
 						NULL,
@@ -784,16 +992,13 @@ static void _midgard_collector_class_init(
 	klass->get_subkey = midgard_collector_get_subkey;
 	klass->merge = midgard_collector_merge;
 	klass->list_keys = midgard_collector_list_keys;
-	klass->remove_key = midgard_collector_remove_key;
-	klass->destroy = midgard_collector_destroy;
+	klass->remove_key = midgard_collector_remove_key;	
 	klass->add_constraint = midgard_collector_add_constraint;
 	klass->begin_group = midgard_collector_begin_group;
 	klass->end_group = midgard_collector_end_group;
 	klass->add_order = midgard_collector_add_order;
 	klass->set_offset = midgard_collector_set_offset;
 	klass->set_limit = midgard_collector_set_limit;
-	klass->set_lang = midgard_collector_set_lang;
-	klass->unset_languages = midgard_collector_unset_languages;
 	klass->count = midgard_collector_count;
 	klass->execute = midgard_collector_execute;
 }
