@@ -74,6 +74,7 @@ static MidgardConfigPrivate *midgard_config_private_new(void)
 		g_new(MidgardConfigPrivate, 1);
         config_private->keyfile = NULL;
 	config_private->log_channel = NULL;
+	config_private->configname = NULL;
 
 	return config_private;
 }
@@ -281,6 +282,7 @@ static void __set_config_from_keyfile(MidgardConfig *self, GKeyFile *keyfile, co
 	tmpstr = g_key_file_get_string(keyfile, "MidgardDatabase", "PamFile", NULL);
 	if(tmpstr == NULL)
 		tmpstr = g_strdup("midgard");
+	g_free (self->pamfile);
 	self->pamfile = g_strdup(tmpstr);
 	g_free(tmpstr);
 
@@ -1149,6 +1151,9 @@ __midgard_config_struct_free (MidgardConfig *self)
 		g_key_file_free (self->priv->keyfile);
 	self->priv->keyfile = NULL;
 
+	g_free (self->priv->configname);
+	self->priv->configname = NULL;
+
 	g_free (self->priv);
 	self->priv = NULL;
 
