@@ -66,6 +66,7 @@ midgard_connection_private_new (void)
 	cnc_private->connection = NULL;
 	cnc_private->cache = NULL;
 	cnc_private->configname = NULL;
+	cnc_private->cnc_str = NULL;
 
 	cnc_private->error_clbk_connected = FALSE;
 	cnc_private->authtypes = NULL;
@@ -80,32 +81,41 @@ midgard_connection_private_new (void)
 	return cnc_private;
 }
 
-static void __midgard_connection_struct_free(MidgardConnection *self, gboolean object)
+static void 
+__midgard_connection_struct_free (MidgardConnection *self, gboolean object)
 {
 	if (self->err != NULL)
-		g_clear_error(&self->err);
+		g_clear_error (&self->err);
 
 	if (self->errstr != NULL) {
-		g_free(self->errstr);
+		g_free (self->errstr);
 		self->errstr = NULL;
 	}
 
 	if (self->priv->authstack) {
-		g_slist_free(self->priv->authstack);
+		g_slist_free (self->priv->authstack);
 		self->priv->authstack = NULL;
 	}
 
-	g_timer_stop(self->priv->timer);
-	gdouble bench = g_timer_elapsed(self->priv->timer, NULL);
-
-	if (self->priv->loghandler) {
-		g_message("MidgardConnection uptime %.04f seconds", bench);
-		g_log_remove_handler(G_LOG_DOMAIN, self->priv->loghandler);
+	if (self->priv->cache) {
+		g_free (self->priv->cache);
+		self->priv->cache = NULL;
 	}
 
-	g_timer_destroy(self->priv->timer);
+	g_free ((gchar *)self->priv->cnc_str);
+	self->priv->cnc_str = NULL;
 
-	g_free(self->priv);
+	g_timer_stop (self->priv->timer);
+	gdouble bench = g_timer_elapsed (self->priv->timer, NULL);
+
+	if (self->priv->loghandler) {
+		g_message ("MidgardConnection uptime %.04f seconds", bench);
+		g_log_remove_handler (G_LOG_DOMAIN, self->priv->loghandler);
+	}
+
+	g_timer_destroy (self->priv->timer);
+
+	g_free (self->priv);
 	self->priv = NULL;
 }
 
@@ -221,7 +231,7 @@ static void _midgard_connection_class_init(
 	gobject_class->dispose = _midgard_connection_dispose;
 	gobject_class->get_property = _midgard_connection_get_property;
 	klass->open = midgard_connection_open;
-	klass->open_config = midgard_connection_open_config;	
+	klass->open_config = midgard_connection_open_config;
 	klass->set_loglevel = midgard_connection_set_loglevel;
 	klass->get_loglevel = midgard_connection_get_loglevel;
 	klass->set_loghandler = midgard_connection_set_loghandler;
