@@ -28,13 +28,12 @@ typedef struct {
 static GHashTable *__copy_hash_table_with_strings(GHashTable *src);
 
 MgdSchemaPropertyAttr* 
-midgard_core_schema_type_property_attr_new (void)
+midgard_core_schema_type_property_attr_new_empty (void)
 {
 	MgdSchemaPropertyAttr *prop = g_new(MgdSchemaPropertyAttr, 1); 
 
-	/* Ensure, default type is string */
-	prop->gtype = G_TYPE_STRING;
-	prop->type = g_strdup("string");
+	prop->gtype = G_TYPE_NONE;
+	prop->type = NULL;
 
 	prop->name = NULL;	
 	prop->default_value = NULL;
@@ -52,6 +51,21 @@ midgard_core_schema_type_property_attr_new (void)
 	prop->is_reversed = FALSE;
 	prop->is_link = FALSE;
 	prop->is_linked = FALSE;
+	prop->description = NULL;
+	prop->user_values = NULL; 
+
+	return prop;
+}
+
+MgdSchemaPropertyAttr *
+midgard_core_schema_type_property_attr_new (void)
+{
+	MgdSchemaPropertyAttr *prop = midgard_core_schema_type_property_attr_new_empty();
+
+	/* Ensure default type is string */
+	prop->gtype = G_TYPE_STRING;
+	prop->type = g_strdup("string");
+
 	prop->description = g_strdup("");
 	prop->user_values = g_hash_table_new_full(g_str_hash, g_str_equal, g_free, g_free);
 
@@ -186,6 +200,30 @@ midgard_core_schema_type_attr_new (void)
 	return type;
 }
 
+void
+midgard_core_schema_type_attr_extend (MgdSchemaTypeAttr *src, MgdSchemaTypeAttr *dst)
+{
+	g_return_if_fail (src != NULL);
+	g_return_if_fail (dst != NULL);
+
+	dst->parentfield = src->parentfield ? g_strdup (src->parentfield) : NULL;
+	dst->upfield = src->upfield ? g_strdup (src->upfield) : NULL;
+	dst->parent = src->parent ? g_strdup (src->parent) : NULL;
+	dst->primary = src->primary ? g_strdup (src->primary) : NULL;
+	dst->property_up = src->property_up ? g_strdup (src->property_up) : NULL;
+	dst->property_parent = src->property_parent ? g_strdup (src->property_parent) : NULL;
+
+	if (src->children) {
+		GSList *children;
+		for (children = src->children; children != NULL; children = children->next) {
+			dst->children = g_slist_append (dst->children, g_strdup ((gchar *) children->data));
+		}
+	}
+	
+	dst->unique_name = src->unique_name ? g_strdup (src->unique_name) : NULL;
+	dst->metadata_class = src->metadata_class ? g_strdup (src->metadata_class) : NULL;
+}
+
 void 
 _destroy_property_hash (gpointer key, gpointer value, gpointer userdata)
 {
@@ -327,7 +365,7 @@ midgard_core_schema_type_add_table (MgdSchemaTypeAttr *type, const gchar *table)
 
 	g_hash_table_insert (type->tableshash, g_strdup(table), NULL);
 
-	GString *_sql = g_string_new (" ");
+	GString *_sql = g_string_new ("");
 	_str_cont *cont = g_new (_str_cont, 1);
 	cont->string = _sql;
 	cont->elts = 0;
