@@ -1,5 +1,5 @@
 /* 
-Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009 Piotr Pokora <piotrek.pokora@gmail.com>
+Copyright (C) 2004, 2005, 2006, 2007, 2008, 2009, 2010 Piotr Pokora <piotrek.pokora@gmail.com>
 Copyright (C) 2004 Alexander Bokovoy <ab@samba.org>
 
 This program is free software; you can redistribute it and/or modify it
@@ -339,6 +339,13 @@ _CHECK_IS_UP_CIRCULAR:
 	if (up_prop == NULL)
 		return FALSE;
 
+	/* Ignore, if up property is a link to different class */
+	MidgardReflectionProperty *mrp = midgard_reflection_property_new (MIDGARD_DBOBJECT_CLASS (klass));
+	const MidgardDBObjectClass *linked_klass = midgard_reflection_property_get_link_class (mrp, up_prop);
+	g_object_unref (mrp);
+	if (MIDGARD_DBOBJECT_CLASS (linked_klass) != MIDGARD_DBOBJECT_CLASS (klass))
+		return FALSE;
+
 	/* we checked up property so "parent" class is of the same type */
 	GValue *idval = g_new0(GValue, 1);
 	g_value_init(idval , G_TYPE_UINT);
@@ -2059,29 +2066,37 @@ MgdObject *midgard_object_get_parent(MgdObject *self)
 	MgdObject *mobj = self;
 	g_assert(mobj != NULL);
 	
-	MgdObject *pobj;
+	MgdObject *pobj = NULL;
 	const gchar *pcstring;
 	guint puint = 0;
 	gint pint = 0;
 	GParamSpec *fprop = NULL;
 	GValue pval = {0,};
 	gboolean ret_object = FALSE;
-
+	const gchar *parent_class_name = NULL;
+	MidgardConnection *mgd = MGD_OBJECT_CNC (self);
 	MidgardObjectClass *klass = MIDGARD_OBJECT_GET_CLASS(mobj);
 	
-	if (klass->dbpriv->storage_data->parent == NULL)
-		return NULL;
-
-	pobj =  midgard_object_new(mobj->dbpriv->mgd , G_OBJECT_TYPE_NAME(mobj), NULL);
-	
-	if (pobj == NULL)
-		return NULL;
-
 	const gchar *property_up = midgard_object_class_get_property_up (klass);
 
-	if (property_up) 
+	if (property_up) {
+
 		fprop = g_object_class_find_property( G_OBJECT_GET_CLASS(mobj), property_up);
-	
+
+		MidgardReflectionProperty *mrp = midgard_reflection_property_new (MIDGARD_DBOBJECT_CLASS (klass));
+		if (midgard_reflection_property_is_link (mrp, property_up)) {
+		
+			parent_class_name = midgard_reflection_property_get_link_name (mrp, property_up);
+			if (parent_class_name)
+				pobj = midgard_object_new (mgd, parent_class_name, NULL);
+			
+			g_object_unref (mrp);
+		}
+		
+		if (!pobj) 
+			return NULL;
+	}
+
 	if (fprop) {
 		
 		g_value_init(&pval,fprop->value_type);
@@ -2146,7 +2161,11 @@ MgdObject *midgard_object_get_parent(MgdObject *self)
 	if (midgard_object_class_get_property_parent(klass) == NULL)
 		return NULL;
 
-	pobj =  midgard_object_new(mobj->dbpriv->mgd , mobj->dbpriv->storage_data->parent, NULL);
+	parent_class_name = midgard_object_parent (self);
+	if (!parent_class_name)
+		return NULL;
+
+	pobj =  midgard_object_new(mobj->dbpriv->mgd , parent_class_name, NULL);
 	
 	if (pobj == NULL)
 		return NULL;
